export interface IglobalLogOptions {
    [key: string]: string | string[] | number | boolean;
    dirPath: string;
    disabledTags: string[];
    filePrefix: string;
    maxMsgLength: number;
    printColor: string;
    printConsole: boolean;
}
/**
 * Returns a string that is formatted for logging.
 * @param {any} msg - A message to be logged.
 * @param {Date} date - Datetime of the log.
 * @param {string} tag - A tag of the log, if any.
 * @param {IglobalLogOptions} options - Custom options, if any.
 */
export declare const getLogStr: (msg: any, date: Date, tag?: string | undefined, options?: IglobalLogOptions | undefined) => string;
/**
 * Prints out a message.
 * @param {any} msg - The message text.
 * @param {string} tag - Tag to be used, if any.
 * @param {IglobalLogOptions} options - Custom options, if any.
 * @param {Date} date - Date, if any.
 */
export declare const print: (msg: any, tag?: string | undefined, options?: IglobalLogOptions | undefined, date?: Date | undefined) => void;
/**
 * Creates a log.
 * @param {string} msg - A message to log and print.
 * @param {string} tag - A tag for the message.
 * @param {boolean} doPrint - Whether to print console.log.
 * @param {object} options - Custom options for the execution.
 */
export declare const log: (msg: string, tag: string, doPrint: boolean, options: IglobalLogOptions) => void;
/**
 * Creates a log (synchronized).
 * @param {string} msg - A message to log and print.
 * @param {string} tag - A tag for the message.
 * @param {boolean} doPrint - Whether to print console.log.
 * @param {object} options - Custom options for the execution.
 */
export declare const logSync: (msg: string, tag: string, doPrint: boolean, options: IglobalLogOptions) => void;
/**
 * Returns the currently active
 * global log options.
 * @returns {object} - The current global log options.
 */
export declare const getGlobalLogOptions: () => IglobalLogOptions;
/**
 * Overrides either some or all of the global log options.
 * @param {object} options - New custom global log options.
 * @returns {object} - The current global log options after the modification.
 */
export declare const setGlobalLogOptions: (options: IglobalLogOptions) => IglobalLogOptions;
/**
 * Sets global log setting: dirPath.
 * @param {string} value
 */
export declare const setDirPath: (value: string) => void;
/**
 * Sets global log setting: disabledTags.
 * @param {string[]} value
 */
export declare const setDisabledTags: (value: string[]) => void;
/**
 * Sets global log setting: filePrefix.
 * @param {string} value
 */
export declare const setFilePrefix: (value: string) => void;
/**
 * Sets global log setting: maxMsgLength.
 * @param {number} value
 */
export declare const setMaxMsgLength: (value: number) => void;
/**
 * Sets global log setting: printColor.
 * @param {string} value
 */
export declare const setPrintColor: (value: string) => void;
/**
 * Sets global log setting: printConsole.
 * @param {boolean} value
 */
export declare const setPrintConsole: (value: boolean) => void;
export declare const testUtil: () => any;
export default log;
